@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.116 2004/01/13 14:54:46 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.117 2004/01/13 23:00:35 fuyu Exp $
  */
 
 #include "config.h"
@@ -807,7 +807,7 @@ open_bulletin_board(OchushaApplication *application,
 
     if (info->is_busy)
       {
-#if DEBUG_THREAD
+#if DEBUG_GUI_MOST
 	fprintf(stderr, "board is busy.\n");
 #endif
 	THREAD_LIST_UNLOCK;
@@ -1249,6 +1249,9 @@ redraw_threadlist_view(OchushaApplication *application,
   {
     if (info->is_busy)
       {
+#if DEBUG_GUI_MOST
+	fprintf(stderr, "Board is busy.\n");
+#endif
 	info->redraw_required = TRUE;
 	THREAD_LIST_UNLOCK;
 	return;
