@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha.h,v 1.11 2003/12/24 05:16:32 fuyu Exp $
+ * $Id: ochusha.h,v 1.12 2003/12/30 17:22:07 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_H_
@@ -111,6 +111,8 @@ void ochusha_config_unlink_directory(const OchushaConfig *config,
 
 gboolean ochusha_config_cache_file_exist(const OchushaConfig *config,
 					 const char *url);
+char *ochusha_config_cache_find_file(const OchushaConfig *config,
+				     const char *url);
 int ochusha_config_cache_open_file(const OchushaConfig *config,
 				   const char *url, int flags);
 void ochusha_config_cache_unlink_file(const OchushaConfig *config,
