@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_async_buffer.h,v 1.8 2003/12/19 03:11:47 fuyu Exp $
+ * $Id: ochusha_async_buffer.h,v 1.10 2004/01/08 19:44:59 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_ASYNCBUF_H_
@@ -99,12 +99,14 @@ OchushaAsyncBuffer *ochusha_async_buffer_new(char *buffer, int length,
 					     DestructFunc *destructor);
 OchushaAsyncBuffer *ochusha_async_buffer_new_with_file(int fd);
 OchushaAsyncBuffer *ochusha_async_buffer_new_with_file_mmap(int fd);
+gboolean ochusha_async_buffer_reset(OchushaAsyncBuffer *buffer);
 
 gboolean ochusha_async_buffer_active_ref(OchushaAsyncBuffer *buffer);
 void ochusha_async_buffer_active_unref(OchushaAsyncBuffer *buffer);
 
 void ochusha_async_buffer_suspend_all(void);
 void ochusha_async_buffer_resume_all(void);
+void ochusha_async_buffer_terminate_all(void);
 
 void ochusha_async_buffer_suspend(OchushaAsyncBuffer *buffer);
 void ochusha_async_buffer_resume(OchushaAsyncBuffer *buffer);
