@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.44 2004/01/13 14:51:37 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.45 2004/01/13 22:58:30 fuyu Exp $
  */
 
 #include "config.h"
@@ -1330,12 +1330,12 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   gboolean signal_result;
   NetworkBrokerJobArgs *args = g_object_get_qdata(G_OBJECT(buffer),
 						  broker_job_args_id);
-  OchushaNetworkBroker *broker = args->broker;
+  OchushaNetworkBroker *broker;
   WorkerSyncObject *sync_object = g_object_get_qdata(G_OBJECT(buffer),
 						     worker_sync_object_id);
   OchushaNetworkBrokerBufferStatus *status
     = g_object_get_qdata(G_OBJECT(buffer), broker_buffer_status_id);
-  char *url = args->url;
+  char *url;
   int len;
   ghttp_request *request = NULL;
   ContentEncodingType content_encoding = UNKNOWN_ENCODING;
@@ -1343,30 +1343,48 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   const char *error_message = NULL;
   gchar message[LOG_MESSAGE_SIZE];
 
-  if (!ochusha_async_buffer_active_ref(buffer))
+  if (args == NULL || !ochusha_async_buffer_active_ref(buffer))
     {
-      g_signal_emit(G_OBJECT(broker),
-		    broker_signals[ACCESS_TERMINATED_SIGNAL],
-		    0,
-		    buffer,
-		    &signal_result);
+      if (args != NULL)
+	{
+	  broker = args->broker;
+	  url = args->url;
+	}
+      else
+	{
+	  broker = NULL;
+	  url = NULL;
+	}
 
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
-      g_signal_emit(G_OBJECT(broker),
-		    broker_signals[ACCESS_FAILED_SIGNAL],
-		    0,
-		    buffer,
-		    OCHUSHA_NETWORK_BROKER_FAILURE_REASON_ACCESS_TERMINATED,
-		    _("Access terminated."),
-		    &signal_result);
+
+      if (broker != NULL)
+	{
+	  g_signal_emit(G_OBJECT(broker),
+			broker_signals[ACCESS_TERMINATED_SIGNAL],
+			0,
+			buffer,
+			&signal_result);
+
+	  g_signal_emit(G_OBJECT(broker),
+			broker_signals[ACCESS_FAILED_SIGNAL],
+			0,
+			buffer,
+			OCHUSHA_NETWORK_BROKER_FAILURE_REASON_ACCESS_TERMINATED,
+			_("Access terminated."),
+			&signal_result);
+	}
 
       ochusha_async_buffer_fix(buffer);
       g_object_set_qdata(G_OBJECT(buffer), broker_job_args_id, NULL);
       OCHU_OBJECT_UNREF(G_OBJECT(buffer));
 
-      snprintf(message, LOG_MESSAGE_SIZE,
-	       _("Access terminated: %s\n"), url);
-      ochusha_network_broker_output_log(broker, message);
+      if (broker != NULL)
+	{
+	  snprintf(message, LOG_MESSAGE_SIZE,
+		   _("Access terminated: %s\n"), url);
+	  ochusha_network_broker_output_log(broker, message);
+	}
 
       LOCK_WORKER_SYNC_OBJECT(sync_object);
       sync_object->finished = TRUE;
@@ -1375,6 +1393,9 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       return;
     }
 
+  broker = args->broker;
+  url = args->url;
+
   if (args->length == 0)
     len = read_cache_to_buffer(broker->config, url, buffer);
   else
@@ -1968,7 +1989,7 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   gboolean signal_result;
   NetworkBrokerJobArgs *args = g_object_get_qdata(G_OBJECT(buffer),
 					      broker_job_args_id);
-  OchushaNetworkBroker *broker = args->broker;
+  OchushaNetworkBroker *broker;
   OchushaNetworkBrokerBufferStatus *status
     = g_object_get_qdata(G_OBJECT(buffer), broker_buffer_status_id);
   gchar message[LOG_MESSAGE_SIZE];
@@ -1977,17 +1998,23 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   fprintf(stderr, "refresh_cache_after_read() thread is invoked.\n");
 #endif
 
-  if (!ochusha_async_buffer_active_ref(buffer))
+  if (args == NULL || !ochusha_async_buffer_active_ref(buffer))
     {
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
-      g_signal_emit(G_OBJECT(broker),
-		    broker_signals[ACCESS_TERMINATED_SIGNAL],
-		    0,
-		    buffer,
-		    &signal_result);
+      if (args != NULL)
+	{
+	  broker = args->broker;
+	  g_signal_emit(G_OBJECT(broker),
+			broker_signals[ACCESS_TERMINATED_SIGNAL],
+			0,
+			buffer,
+			&signal_result);
+	}
       goto finish_refresh_cache_after_read;
     }
 
+  broker = args->broker;
+
   status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_DIRECT_ACCESS;
 
   if (http_read_from_url(broker, buffer))
@@ -2083,7 +2110,7 @@ force_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   gboolean signal_result;
   NetworkBrokerJobArgs *args = g_object_get_qdata(G_OBJECT(buffer),
 					      broker_job_args_id);
-  OchushaNetworkBroker *broker = args->broker;
+  OchushaNetworkBroker *broker;
   OchushaNetworkBrokerBufferStatus *status
     = g_object_get_qdata(G_OBJECT(buffer), broker_buffer_status_id);
 
@@ -2091,17 +2118,23 @@ force_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   fprintf(stderr, "force_read() thread is invoked.\n");
 #endif
 
-  if (!ochusha_async_buffer_active_ref(buffer))
+  if (args == NULL || !ochusha_async_buffer_active_ref(buffer))
     {
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
-      g_signal_emit(G_OBJECT(broker),
-		    broker_signals[ACCESS_TERMINATED_SIGNAL],
-		    0,
-		    buffer,
-		    &signal_result);
+      if (args != NULL)
+	{
+	  broker = args->broker;
+	  g_signal_emit(G_OBJECT(broker),
+			broker_signals[ACCESS_TERMINATED_SIGNAL],
+			0,
+			buffer,
+			&signal_result);
+	}
       goto finish_force_read;
     }
 
+  broker = args->broker;
+
   status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_DIRECT_ACCESS;
 
   if (args->if_modified_since != NULL)
@@ -2572,7 +2605,7 @@ force_read_synchronously(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   gboolean signal_result;
   NetworkBrokerJobArgs *args = g_object_get_qdata(G_OBJECT(buffer),
 					      broker_job_args_id);
-  OchushaNetworkBroker *broker = args->broker;
+  OchushaNetworkBroker *broker;
   OchushaNetworkBrokerBufferStatus *status
     = g_object_get_qdata(G_OBJECT(buffer), broker_buffer_status_id);
 
@@ -2583,13 +2616,18 @@ force_read_synchronously(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   if (!ochusha_async_buffer_active_ref(buffer))
     {
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
-      g_signal_emit(G_OBJECT(broker),
-		    broker_signals[ACCESS_TERMINATED_SIGNAL],
-		    0,
-		    buffer,
-		    &signal_result);
+      if (args != NULL)
+	{
+	  broker = args->broker;
+	  g_signal_emit(G_OBJECT(broker),
+			broker_signals[ACCESS_TERMINATED_SIGNAL],
+			0,
+			buffer,
+			&signal_result);
+	}
       goto finish_force_read;
     }
+  broker = args->broker;
 
   status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_DIRECT_ACCESS;
 
