@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.h,v 1.9 2003/12/29 08:48:16 fuyu Exp $
+ * $Id: utils.h,v 1.10 2004/01/13 14:52:49 fuyu Exp $
  */
 
 #ifndef _UTILS_H_
@@ -78,12 +78,6 @@ char *ochusha_utils_find_cgi_query_key(const char *src,
 int mkdir_p(const char *path);
 
 
-#if DEBUG_REF_COUNT
-void ochu_object_ref(GObject *object);
-void ochu_object_unref(GObject *object);
-#endif
-
-
 #if TRACE_MEMORY_USAGE
 /*
  * ꡼åϢ
@@ -95,6 +89,17 @@ void dump_pointers(void);
 #endif
 
 
+#if TRACE_REFCOUNT
+void init_refcount_trace(void);
+void trace_register_g_object(GObject *object, const char *file, int line);
+void trace_g_object_ref(GObject *object, const char *file, int line);
+void trace_g_object_unref(GObject *object, const char *file, int line);
+void ochu_object_ref(GObject *object);
+void ochu_object_unref(GObject *object);
+void dump_objects(void);
+#endif
+
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
