@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ts_engine.c,v 1.4 2003/12/29 18:44:17 fuyu Exp $
+ * $Id: ts_engine.c,v 1.5 2003/12/31 16:53:19 fuyu Exp $
  */
 
 #include "config.h"
@@ -591,7 +591,7 @@ ts_engine_vevalf0(TSEngine *engine,
 	      if (!post_percent_state)
 		break;
 
-	      value = ts_core_mk_cell_character(ts_core, va_arg(ap, char));
+	      value = ts_core_mk_cell_character(ts_core, va_arg(ap, int));
 	      ts_core->args = ts_core_mk_cell_cons(ts_core, value,
 						   ts_core->args, 0);
 	      post_percent_state = FALSE;
@@ -673,6 +673,7 @@ ts_engine_vevalf(TSEngine *engine,
     {
       gboolean post_percent_state = FALSE;
       gboolean long_argument = FALSE;
+      TSCellHandle *handle;
       TSCell *value;
 
       while (*fmt != '\0')
@@ -719,9 +720,8 @@ ts_engine_vevalf(TSEngine *engine,
 	      if (!post_percent_state)
 		break;
 
-	      value = ts_core_mk_cell_character(ts_core, va_arg(ap, char));
-	      ts_core->args = ts_core_mk_cell_cons(ts_core,
-						   va_arg(ap, TSCell *),
+	      value = ts_core_mk_cell_character(ts_core, va_arg(ap, int));
+	      ts_core->args = ts_core_mk_cell_cons(ts_core, value,
 						   ts_core->args, 0);
 	      post_percent_state = FALSE;
 	      long_argument = FALSE;
@@ -731,8 +731,9 @@ ts_engine_vevalf(TSEngine *engine,
 	      if (!post_percent_state)
 		break;
 
-	      ts_core->args = ts_core_mk_cell_cons(ts_core,
-						   va_arg(ap, TSCell *),
+	      handle = va_arg(ap, TSCellHandle *);
+	      value = TS_IS_CELL_HANDLE(handle) ? handle->cell : ts_core->nil;
+	      ts_core->args = ts_core_mk_cell_cons(ts_core, value,
 						   ts_core->args, 0);
 	      post_percent_state = FALSE;
 	      long_argument = FALSE;
